#[unsafe(no_mangle)]pub unsafe extern "C" fn getgrent() -> *mut groupExpand description
MT-Unsafe race:grent race:grentbuf locale
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/endgrent.html.
Returns a pointer to a structure containing the broken-out fields of an entry in the group database.